@@ -262,6 +262,7 @@ class TestOLT(unittest.TestCase):
         add_ont(olt2.module.next_neu, pon_port, pon, '000003000001', None, brmacs)
         brmacs = ['00:01:00:00:00:04'] if bridged_macs else None
         add_ont(olt2.module.next_neu, pon_port, pon, '000003000002', None, brmacs)
+        olt2.module.next_neu.peers[1].serial_number = None  # have one with no serno
 
         olt3 = Olt(self.ctx, 'olt3', 'Element with no PON', 'MySite', FakeClient('ip3'), None, 'olt', None)
         olt3.module = FakeModule()
@@ -314,8 +315,8 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 3)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
 
@@ -326,8 +327,8 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 3)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
 
@@ -339,7 +340,7 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 2)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
 
@@ -361,12 +362,12 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 7)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -380,11 +381,11 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 7)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -395,10 +396,10 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 6)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -411,11 +412,11 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 7)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -427,9 +428,9 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 5)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -455,12 +456,12 @@ class TestOLT(unittest.TestCase):
         self.assertEqual(cpe_mac_refs, {
             '00:00:03:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:03:00:00:01', attributes={'ap': 'bh1', 'sm': '00:00:03:00:00:01'}),
             '00:00:01:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:01:00:00:01', attributes={'ap': 'bh1', 'sm': '00:00:03:00:00:01'}),
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -484,10 +485,10 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 8)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '0a:0a:0a:0a:0a:0a': NetworkMetadataReference(type='cpe_mac', value='0a:0a:0a:0a:0a:0a', attributes={'ap': 'ap1', 'sm': '0a:0a:0a:0a:0a:0a'}),
@@ -513,11 +514,11 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 6)
         self.assertEqual(cpe_mac_refs, {
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
@@ -544,11 +545,11 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 7)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001'}),
-            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
         })
@@ -560,10 +561,10 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 6)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001'}),
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
         })
@@ -576,9 +577,9 @@ class TestOLT(unittest.TestCase):
         cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
         self.assertEqual(len(cpe_mac_refs), 5)
         self.assertEqual(cpe_mac_refs, {
-            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
-            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
-            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
         })
